| mx_get_state | R Documentation |
Read-side counterpart of mx_set_state, e.g. to check
whether a room is encrypted before joining the send path.
mx_get_state(session, room_id, event_type, state_key = "")
session |
An "mx_session" object. |
room_id |
Character. The room ID. |
event_type |
Character. State event type, e.g.
|
state_key |
Character. State key (default empty string). |
The state event content as a list, or NULL when the state event is not set.
## Not run:
enc <- mx_get_state(s, "!abc:example", "m.room.encryption")
is.null(enc) # FALSE in an encrypted room
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.