| mx_keys_query | R Documentation |
POST /_matrix/client/v3/keys/query. Each entry in
device_keys maps a Matrix user id to a character vector of
device ids to request. An empty character vector requests all of
the user's devices.
mx_keys_query(session, device_keys, timeout = 10000L)
session |
An |
device_keys |
Named list. Names are Matrix user ids
(e.g. |
timeout |
Integer milliseconds. Time the server should wait for remote homeservers before returning a partial result. |
Parsed response with a device_keys map of
user_id -> device_id -> device_keys_object.
## Not run:
mx_keys_query(s, list("@alice:example.org" = character()))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.