mx_login: Log in to a Matrix homeserver

View source: R/session.R

mx_loginR Documentation

Log in to a Matrix homeserver

Description

Authenticates with a Matrix homeserver using password login and returns a session object carrying the access token and device id.

Usage

mx_login(server, user, password, device_id = NULL)

Arguments

server

Character. Homeserver base URL (e.g. "https://matrix.example").

user

Character. User localpart or full Matrix ID.

password

Character. Account password.

device_id

Character or NULL. Reuse an existing device id.

Value

An object of class "mx_session".

Examples

## Not run: 
s <- mx_login("https://matrix.example", "alice", "hunter2")

## End(Not run)

mx.api documentation built on Sept. 12, 2026, 1:07 a.m.