| mx_keys_device_signing_upload | R Documentation |
POST /_matrix/client/v3/keys/device_signing/upload. The key
objects must already carry the signatures required by the Matrix
cross-signing specification. Homeservers normally require user-interactive
authentication (UIA); the initial 401 response contains a session id which
the caller supplies in a completed auth object on retry.
mx_keys_device_signing_upload(
session,
master_key = NULL,
self_signing_key = NULL,
user_signing_key = NULL,
auth = NULL
)
session |
An |
master_key |
A signed Matrix CrossSigningKey object or NULL. |
self_signing_key |
A CrossSigningKey signed by the master key, or NULL. |
user_signing_key |
A CrossSigningKey signed by the master key, or NULL. |
auth |
Completed UIA authentication object or NULL. |
Parsed homeserver response.
## Not run:
mx_keys_device_signing_upload(s, master_key = master,
self_signing_key = self, user_signing_key = user,
auth = list(type = "m.login.password", session = uia_session,
identifier = list(type = "m.id.user", user = "bot"),
password = "secret"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.