| mx_login | R Documentation |
Authenticates with a Matrix homeserver using password login and returns a session object carrying the access token and device id.
mx_login(server, user, password, device_id = NULL)
server |
Character. Homeserver base URL (e.g. "https://matrix.example"). |
user |
Character. User localpart or full Matrix ID. |
password |
Character. Account password. |
device_id |
Character or NULL. Reuse an existing device id. |
An object of class "mx_session".
## Not run:
s <- mx_login("https://matrix.example", "alice", "hunter2")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.